#!/usr/bin/perl

use strict;
use warnings;
use FDN::Common::Config;

if ( $#ARGV<1 || $ARGV[0] eq '-h' ) {
	print STDERR <<EOF ;
$0 <file.cfg> <section> [key]

Prints on STDOUT the value of the required key in the config file.

If no key is provided, then all the keys of the section are printed
one per line, the first word of the line being the name of the key, and
ensuring there is no blank in the key name.

If a key is a list (\@key in the file), it is printed out as many times
as there are values.

val=`$0 /etc/some/config.cfg section key`
$0 /etc/conf.cfg section | while read key val; do
	some_stuff \$key \$val
done
$0 /etc/conf.cfg section \@elems | while read value; do
	some_stuff \$value
done
EOF
	exit(1);
}

my $file = $ARGV[0];
my $section = $ARGV[1];
my $key = $ARGV[2];

if ( defined $key ) {
	my $val = Config_Key($file, $section, $key);
	if ( ! defined $val ) {
		print "\n";
		exit(0);
	}
	if ( ! ref($val ) ) {
		print $val."\n";
		exit(0);
	}
	if ( ref($val) eq 'ARRAY' ) {
		for my $v ( @$val ) {
			print $v."\n";
		}
		exit(0);
	}
	print STDERR "Failed to read key in file";
	exit(1);
}

my $sect = Config_Section($file, $section);
if ( ! defined $sect || !ref($sect) || ref($sect) ne 'HASH' ) {
	print STDERR "Failed to read section in file";
	exit(1);
}

my ( $k, $v );
while ( ( $k, $v ) = each %$sect ) {
	$k =~ s/\s+/_/g;
	if ( ref($v) eq 'ARRAY' ) {
		for my $vv ( @$v ) {
			print "$k $vv\n";
		}
		next;
	}
	print "$k $v\n";
}
exit(0);

